@@ -11,7 +11,7 @@ use File::HomeDir::Darwin ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.96_04';
+	$VERSION = '0.88';
 
 	# This is only a child class of the pure Perl darwin
 	# class so that we can do homedir detection of all three
@@ -110,13 +110,13 @@ sub _find_folder {
 		Mac::Files::kUserDomain(),
 		$name,
 	);
-	return undef unless defined $folder;
+	return unless defined $folder;
 
 	unless ( -d $folder ) {
 		# Make sure that symlinks resolve to directories.
-		return undef unless -l $folder;
+		return unless -l $folder;
 		my $dir = readlink $folder or return;
-		return undef unless -d $dir;
+		return unless -d $dir;
 	}
 
 	return Cwd::abs_path($folder);
@@ -173,7 +173,7 @@ sub _to_user {
 
 =head1 NAME
 
-File::HomeDir::Darwin - Find your home and other directories on Darwin (OS X)
+File::HomeDir::Darwin - Find your home and other directories, on Darwin (OS X)
 
 =head1 DESCRIPTION
 
