@@ -8,7 +8,7 @@ use File::HomeDir::Darwin ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.96_04';
+	$VERSION = '0.88';
 	@ISA     = 'File::HomeDir::Darwin';
 
 	# Load early if in a forking environment and we have
@@ -111,18 +111,18 @@ sub my_videos {
 }
 
 sub _find_folder {
-	my $class = shift;
-	my $name  = shift;
+	my $class  = shift;
+	my $name   = shift;
 
 	require Mac::SystemDirectory;
 	my $folder = Mac::SystemDirectory::FindDirectory($name);
-	return undef unless defined $folder;
+	return unless defined $folder;
 
 	unless ( -d $folder ) {
 		# Make sure that symlinks resolve to directories.
-		return undef unless -l $folder;
+		return unless -l $folder;
 		my $dir = readlink $folder or return;
-		return undef unless -d $dir;
+		return unless -d $dir;
 	}
 
 	return Cwd::abs_path($folder);
@@ -134,7 +134,7 @@ sub _find_folder {
 
 =head1 NAME
 
-File::HomeDir::Darwin::Cocoa - Find your home and other directories on Darwin (OS X)
+File::HomeDir::Darwin::Cocoa - Find your home and other directories, on Darwin (OS X)
 
 =head1 DESCRIPTION
 
@@ -146,13 +146,13 @@ used via L<File::HomeDir>.
 Theoretically, this should return the same paths as both of the other
 Darwin drivers.
 
-Because this module requires L<Mac::SystemDirectory>, if the module
-is not installed, L<File::HomeDir> will fall back to L<File::HomeDir::Darwin>.
+Because this module requires Mac::SystemDirectory, if the module
+is not installed, File::HomeDir will fall back to L<File::HomeDir::Darwin>.
 
 =head1 SYNOPSIS
 
   use File::HomeDir;
-  
+
   # Find directories for the current user
   $home    = File::HomeDir->my_home;      # /Users/mylogin
   $desktop = File::HomeDir->my_desktop;   # /Users/mylogin/Desktop
